/// <reference types="node" />
import { APIClient, APIFetchOptions, BrowserStackOptions } from './api-client.ts';
import { components, operations } from './generated/openapi.ts';
import type { ChildProcess } from "node:child_process";
export type LocalTestingOptions = Omit<BrowserStackOptions, "username">;
/**
 * Represents a client for interacting with the BrowserStack Local API.
 */
export declare class LocalTestingClient extends APIClient {
    private readonly authToken;
    /**
     * Constructs a new instance of the ScreenshotsClient class.
     * @param options - Optional configuration options for the client.
     */
    constructor(options?: LocalTestingOptions);
    /**
     * Retrieves a list of recent Local binary instances from the server.
     *
     * @param options - The fetch options for the request.
     * @returns A promise that resolves to a fetch response containing the list of active Local instances.
     */
    getBinaryInstances(query?: Omit<operations["getLocalBinaryInstances"]["parameters"]["query"], "auth_token">, options?: APIFetchOptions<operations["getLocalBinaryInstances"]>): Promise<components["schemas"]["LocalBinaryInstance"][]>;
    /**
     * Retrieves details of a Local binary instance from the server.
     *
     * @param localInstanceId The ID of the local binary instance to retrieve.
     * @param query Optional query parameters for the request.
     * @param options Optional fetch options for the request.
     * @returns A promise that resolves to the retrieved local binary instance.
     * @throws {BrowserStackError} If no local binary instance is found with the specified ID.
     */
    getBinaryInstance(localInstanceId: string, query?: Omit<operations["getLocalBinaryInstances"]["parameters"]["query"], "auth_token">, options?: APIFetchOptions<operations["getLocalBinaryInstance"]>): Promise<components["schemas"]["LocalBinaryInstance"]>;
    /**
     * Disconnects a binary instance.
     *
     * @param localInstanceId - The ID of the local binary instance to disconnect.
     * @param query - Optional query parameters for the request.
     * @param options - Optional API fetch options.
     * @returns A promise that resolves to a string representing the message from the server.
     */
    disconnectBinaryInstance(localInstanceId: string, query?: Omit<operations["disconnectLocalBinaryInstance"]["parameters"]["query"], "auth_token">, options?: APIFetchOptions<operations["disconnectLocalBinaryInstance"]>): Promise<string>;
    /**
     * Downloads the BrowserStackLocal binary for the specified operating system architecture and saves it to the specified file path.
     * Note that the file is downloaded to memory for the unzip operation.
     * If the file is large, this method may fail with an out of memory error.
     * This method is intended for use in Node.js environments and will fail in the browser.
     *
     * @param osArch - The operating system architecture for which to download the binary.
     * @param dirPath - The file path where the binary will be saved.
     * @param filenamePrefix - The prefix for the downloaded binary file name inside the ZIP file. Default is "BrowserStackLocal".
     * @param fileMode - The file mode to set for the downloaded binary file. Default is 0o755.
     * @param options - Additional options for the API fetch request.
     * @returns A Promise that resolves when the binary is successfully downloaded and saved.
     */
    downloadBinary(osArch: operations["downloadLocalBinary"]["parameters"]["path"]["osArch"], dirPath: string, filenamePrefix?: string, fileMode?: number, options?: APIFetchOptions<operations["downloadLocalBinary"]>): Promise<string>;
    /**
     * Runs the downloaded Local binary file with the specified flags and options.
     *
     * @param binFilePath - The path to the executable binary file.
     * @param flags - An array of flags to pass to the executable.
     * @param onData - A callback function to handle stdout data received from the executable.
     * @param onError - A callback function to handle stderr data received from the executable.
     * @param startTimeout - The timeout duration in milliseconds for the executable to start.
     * @param stdoutSuccessMessage - The success message to look for in the stdout of the executable.
     * @returns A promise that resolves with the child process when the executable starts successfully.
     * @throws If an error occurs while executing the binary file.
     */
    runBinary(binFilePath: string, flags?: LocalBinaryFlag[], onData?: (data: string) => void, onError?: (data: string) => void, startTimeout?: number, stdoutSuccessMessage?: string): Promise<ChildProcess>;
}
export type LocalBinaryFlag = string;
